This patch makes it possible to turn on printing neighbor description in
"sh ip[v6] bg su".
			    Tomas Janousek <tomi@nomi.cz>


diff -Naur quagga-0.96.3.orig/bgpd/bgp_vty.c quagga-0.96.3/bgpd/bgp_vty.c
--- quagga-0.96.3.orig/bgpd/bgp_vty.c	2003-08-13 02:32:50.000000000 +0200
+++ quagga-0.96.3/bgpd/bgp_vty.c	2004-11-20 15:08:04.000000000 +0100
@@ -39,6 +39,9 @@
 #include "bgpd/bgp_route.h"
 #include "bgpd/bgp_zebra.h"
 
+/* Extern host structure from command.c */
+extern struct host host;
+
 /* Utility function to get address family from current node.  */
 afi_t
 bgp_node_afi (struct vty *vty)
@@ -5929,6 +5932,7 @@
 
   /* Header string for each address family. */
   static char header[] = "Neighbor        V    AS MsgRcvd MsgSent   TblVer  InQ OutQ Up/Down  State/PfxRcd";
+  static char header_desc[] = "  Description";
 
   LIST_LOOP (bgp->peer, peer, nn)
     {
@@ -5949,7 +5953,10 @@
 	      if (CHECK_FLAG(bgp->af_flags[afi][safi], BGP_CONFIG_DAMPENING))
 		vty_out (vty, "Dampening enabled.%s", VTY_NEWLINE);
 	      vty_out (vty, "%s", VTY_NEWLINE);
-	      vty_out (vty, "%s%s", header, VTY_NEWLINE);
+	      vty_out (vty, "%s", header);
+	      if (host.summary_desc)
+		vty_out (vty, "%s", header_desc);
+	      vty_out (vty, "%s", VTY_NEWLINE);
 	    }
 	  count++;
 
@@ -5984,7 +5991,7 @@
 
 	  if (peer->status == Established)
 	    {
-	      vty_out (vty, " %8ld", peer->pcount[afi][safi]);
+	      vty_out (vty, " %8ld    ", peer->pcount[afi][safi]);
 	    }
 	  else
 	    {
@@ -5993,9 +6000,12 @@
 	      else if (CHECK_FLAG (peer->sflags, PEER_STATUS_PREFIX_OVERFLOW))
 		vty_out (vty, " Idle (PfxCt)");
 	      else
-		vty_out (vty, " %-11s", LOOKUP(bgp_status_msg, peer->status));
+		vty_out (vty, " %-12s", LOOKUP(bgp_status_msg, peer->status));
 	    }
 
+	  if (host.summary_desc)
+	    vty_out (vty, "  %s", peer->desc);
+
 	  vty_out (vty, "%s", VTY_NEWLINE);
 	}
     }
diff -Naur quagga-0.96.3.orig/lib/command.c quagga-0.96.3/lib/command.c
--- quagga-0.96.3.orig/lib/command.c	2003-08-21 22:28:24.000000000 +0200
+++ quagga-0.96.3/lib/command.c	2004-11-20 15:09:24.000000000 +0100
@@ -556,6 +556,9 @@
 
   if (host.advanced)
     vty_out (vty, "service advanced-vty%s", VTY_NEWLINE);
+  
+  if (host.summary_desc)
+    vty_out (vty, "service summary-desc%s", VTY_NEWLINE);
 
   if (host.encrypt)
     vty_out (vty, "service password-encryption%s", VTY_NEWLINE);
diff -Naur quagga-0.96.3.orig/lib/command.h quagga-0.96.3/lib/command.h
--- quagga-0.96.3.orig/lib/command.h	2002-12-13 21:15:29.000000000 +0100
+++ quagga-0.96.3/lib/command.h	2004-11-20 13:58:38.000000000 +0100
@@ -58,6 +58,7 @@
   /* Flags for services */
   int advanced;
   int encrypt;
+  int summary_desc;
 
   /* Banner configuration. */
   char *motd;
diff -Naur quagga-0.96.3.orig/lib/vty.c quagga-0.96.3/lib/vty.c
--- quagga-0.96.3.orig/lib/vty.c	2003-07-15 14:52:22.000000000 +0200
+++ quagga-0.96.3/lib/vty.c	2004-11-20 14:01:21.000000000 +0100
@@ -2594,6 +2594,27 @@
   return CMD_SUCCESS;
 }
 
+DEFUN (service_summary_desc,
+       service_summary_desc_cmd,
+       "service summary-desc",
+       "Set up miscellaneous service\n"
+       "Enable description in summary\n")
+{
+  host.summary_desc = 1;
+  return CMD_SUCCESS;
+}
+
+DEFUN (no_service_summary_desc,
+       no_service_summary_desc_cmd,
+       "no service summary-desc",
+       NO_STR
+       "Set up miscellaneous service\n"
+       "Enable description in summary\n")
+{
+  host.summary_desc = 0;
+  return CMD_SUCCESS;
+}
+
 DEFUN (terminal_monitor,
        terminal_monitor_cmd,
        "terminal monitor",
@@ -2812,6 +2833,8 @@
   install_element (CONFIG_NODE, &line_vty_cmd);
   install_element (CONFIG_NODE, &service_advanced_vty_cmd);
   install_element (CONFIG_NODE, &no_service_advanced_vty_cmd);
+  install_element (CONFIG_NODE, &service_summary_desc_cmd);
+  install_element (CONFIG_NODE, &no_service_summary_desc_cmd);
   install_element (CONFIG_NODE, &show_history_cmd);
   install_element (ENABLE_NODE, &terminal_monitor_cmd);
   install_element (ENABLE_NODE, &terminal_no_monitor_cmd);
